Parsing chord information
chordParsing.RdhumdrumR includes an easy-to-use but powerful system for parsing tertian harmony information:
various basic chord representations (including numeric and character-string representations) can be "parsed"—read
and interpreted by humdrumR.
For the most part, parsing automatically happens "behind the scenes" whenever you use any humdrumR chord function, like harm()
roman(), or chord().
Usage
tertianSet(...)
# S3 method for class 'tertianSet'
tertianSet(x, ...)
# S3 method for class 'logical'
tertianSet(x, ...)
# S3 method for class '`NULL`'
tertianSet(x, ...)
# S3 method for class 'numeric'
tertianSet(x)
# S3 method for class 'integer'
tertianSet(x)
# S3 method for class 'character'
tertianSet(x, ..., Exclusive = NULL, multiDispatch = FALSE)
# S3 method for class 'factor'
tertianSet(x, Exclusive = NULL, ...)
# S3 method for class 'token'
tertianSet(x, Exclusive = NULL, ...)See also
All humdrumR chord functions make use of the deparsing functionality.