Humdrum key interpretation
key.RdHumdrum key interpretation
Usage
key(x, ..., Key = NULL, parseArgs = list())Arguments
- x
Input data, interpreted as diatonic keys.
Must be an
atomicvector.- Key
The key used by the parser, deparser, and transposer.
Defaults to
NULL.Must be a
diatonicSetor something coercable todiatonicSet; must be either length1orlength(x)- parseArgs
An optional list of arguments passed to the key parser.
Defaults to an empty
list().Must be a
listof named arguments to the key parser.
Examples
key(c('I', 'ii', 'ii:dor', 'v', '-vi', 'V/V', 'ii/V'))
#> [1] "*C:" "*d:" "*d:dor" "*g:" "*a-:" "*G:" "*d:"