"Unfold" data into multiple stops
unfoldStops.RdIf some record/spine/path locations have different numbers of stops in different fields, this function spreads the data from the smaller fields into multiple stops.
Usage
unfoldStops(humdrumR, fromFields = fields(humdrumR, "D")$Name)